@@ -23,8 +23,6 @@ static const gchar *extended_keywords[] = {
 	"apt", "apartment", "suite", NULL
 };
 
-
-
 static gboolean
 e_address_western_is_line_blank (gchar *line)
 {
@@ -42,8 +40,6 @@ e_address_western_is_line_blank (gchar *line)
 	return blank;
 }
 
-
-
 /* In the array of lines, `lines', we will erase the line at line_num, and
  shift the remaining lines, up to line number num_lines, up one position. */
 
@@ -62,7 +58,6 @@ e_address_western_shift_line (gchar *lines[], gint line_num, gint num_lines)
 	}
 }
 
-
 static void
 e_address_western_remove_blank_lines (gchar *lines[], gint *linecntr)
 {
@@ -84,7 +79,6 @@ e_address_western_remove_blank_lines (gchar *lines[], gint *linecntr)
 	}
 }
 
-
 static gboolean
 e_address_western_is_po_box (gchar *line)
 {
@@ -93,7 +87,6 @@ e_address_western_is_po_box (gchar *line)
 	/* In which phase of processing are we? */
 	enum State { FIRSTCHAR, SECONDCHAR, WHITESPACE } state;
 
-
 	/* If the first two letters of the line are `p' and `o', and these
 	 are in turn followed by whitespace before another letter, then I
 	 will deem the line a representation of a PO Box address. */
@@ -216,7 +209,6 @@ e_address_western_extract_locality (gchar *line)
 		return g_strndup (line, index);
 }
 
-
 /* Whatever resides between the comma and the start of the
   postal code is deemed to be the region. */
 
@@ -311,12 +303,9 @@ e_address_western_parse (const gchar *in_address)
 	gint linecntr, lineindex;
 	gchar *address;
 	gint cntr;
-	gboolean found_po_box, found_postal;
+	gboolean found_postal;
 
 	EAddressWestern *eaw;
-#if 0
-	gint start, end;  /* To be used to classify address lines. */
-#endif
 
 	if (in_address == NULL)
 		return NULL;
@@ -371,14 +360,12 @@ e_address_western_parse (const gchar *in_address)
 	e_address_western_remove_blank_lines (lines, &linecntr);
 
 	/* Let's just test these functions. */
-	found_po_box = FALSE;
 	found_postal = FALSE;
 
 	for (cntr = 0; cntr < linecntr; cntr++)  {
 		if (e_address_western_is_po_box (lines[cntr])) {
 			if (eaw->po_box == NULL)
 				eaw->po_box = e_address_western_extract_po_box (lines[cntr]);
-			found_po_box = TRUE;
 		}
 		else if (e_address_western_is_postal (lines[cntr])) {
 			if (eaw->locality == NULL)
