@@ -609,7 +609,7 @@ e_book_query_from_string  (const gchar *query_string)
 
 	sexp = e_sexp_new();
 
-	for (i=0;i<sizeof(symbols)/sizeof(symbols[0]);i++) {
+	for (i = 0; i < G_N_ELEMENTS (symbols); i++) {
 		if (symbols[i].type == 1) {
 			e_sexp_add_ifunction(sexp, 0, symbols[i].name,
 					     (ESExpIFunc *)symbols[i].func, &list);
@@ -729,13 +729,19 @@ e_book_query_to_string    (EBookQuery *q)
 GType
 e_book_query_get_type (void)
 {
-	static GType type_id = 0;
+	static volatile gsize type_id__volatile = 0;
+
+	if (g_once_init_enter (&type_id__volatile)) {
+		GType type_id;
 
-	if (!type_id)
 		type_id = g_boxed_type_register_static ("EBookQuery",
 							(GBoxedCopyFunc) e_book_query_copy,
 							(GBoxedFreeFunc) e_book_query_unref);
-	return type_id;
+
+		g_once_init_leave (&type_id__volatile, type_id);
+	}
+
+	return type_id__volatile;
 }
 
 /**
