@@ -12,8 +12,10 @@
 
 #include "e-book-backend-sync.h"
 
+G_DEFINE_TYPE (EBookBackendSync, e_book_backend_sync, E_TYPE_BOOK_BACKEND)
+
 struct _EBookBackendSyncPrivate {
-  int mumble;
+  gint mumble;
 };
 
 static GObjectClass *parent_class;
@@ -48,7 +50,7 @@ EBookBackendSyncStatus
 e_book_backend_sync_create_contact (EBookBackendSync *backend,
 				    EDataBook *book,
 				    guint32 opid,
-				    const char *vcard,
+				    const gchar *vcard,
 				    EContact **contact)
 {
 	g_return_val_if_fail (E_IS_BOOK_BACKEND_SYNC (backend), GNOME_Evolution_Addressbook_OtherError);
@@ -133,7 +135,7 @@ EBookBackendSyncStatus
 e_book_backend_sync_modify_contact (EBookBackendSync *backend,
 				    EDataBook *book,
 				    guint32 opid,
-				    const char *vcard,
+				    const gchar *vcard,
 				    EContact **contact)
 {
 	g_return_val_if_fail (E_IS_BOOK_BACKEND_SYNC (backend), GNOME_Evolution_Addressbook_OtherError);
@@ -162,8 +164,8 @@ EBookBackendSyncStatus
 e_book_backend_sync_get_contact (EBookBackendSync *backend,
 				 EDataBook *book,
 				 guint32 opid,
-				 const char *id,
-				 char **vcard)
+				 const gchar *id,
+				 gchar **vcard)
 {
 	g_return_val_if_fail (E_IS_BOOK_BACKEND_SYNC (backend), GNOME_Evolution_Addressbook_OtherError);
 	g_return_val_if_fail (E_IS_DATA_BOOK (book), GNOME_Evolution_Addressbook_OtherError);
@@ -192,7 +194,7 @@ EBookBackendSyncStatus
 e_book_backend_sync_get_contact_list (EBookBackendSync *backend,
 				      EDataBook *book,
 				      guint32 opid,
-				      const char *query,
+				      const gchar *query,
 				      GList **contacts)
 {
 	g_return_val_if_fail (E_IS_BOOK_BACKEND_SYNC (backend), GNOME_Evolution_Addressbook_OtherError);
@@ -223,7 +225,7 @@ EBookBackendSyncStatus
 e_book_backend_sync_get_changes (EBookBackendSync *backend,
 				 EDataBook *book,
 				 guint32 opid,
-				 const char *change_id,
+				 const gchar *change_id,
 				 GList **changes)
 {
 	g_return_val_if_fail (E_IS_BOOK_BACKEND_SYNC (backend), GNOME_Evolution_Addressbook_OtherError);
@@ -253,9 +255,9 @@ EBookBackendSyncStatus
 e_book_backend_sync_authenticate_user (EBookBackendSync *backend,
 				       EDataBook *book,
 				       guint32 opid,
-				       const char *user,
-				       const char *passwd,
-				       const char *auth_method)
+				       const gchar *user,
+				       const gchar *passwd,
+				       const gchar *auth_method)
 {
 	g_return_val_if_fail (E_IS_BOOK_BACKEND_SYNC (backend), GNOME_Evolution_Addressbook_OtherError);
 	g_return_val_if_fail (E_IS_DATA_BOOK (book), GNOME_Evolution_Addressbook_OtherError);
@@ -366,7 +368,7 @@ static void
 _e_book_backend_create_contact (EBookBackend *backend,
 				EDataBook    *book,
 				guint32       opid,
-				const char   *vcard)
+				const gchar   *vcard)
 {
 	EBookBackendSyncStatus status;
 	EContact *contact = NULL;
@@ -400,7 +402,7 @@ static void
 _e_book_backend_modify_contact (EBookBackend *backend,
 				EDataBook    *book,
 				guint32       opid,
-				const char   *vcard)
+				const gchar   *vcard)
 {
 	EBookBackendSyncStatus status;
 	EContact *contact = NULL;
@@ -417,10 +419,10 @@ static void
 _e_book_backend_get_contact (EBookBackend *backend,
 			     EDataBook    *book,
 			     guint32       opid,
-			     const char   *id)
+			     const gchar   *id)
 {
 	EBookBackendSyncStatus status;
-	char *vcard = NULL;
+	gchar *vcard = NULL;
 
 	status = e_book_backend_sync_get_contact (E_BOOK_BACKEND_SYNC (backend), book, opid, id, &vcard);
 
@@ -434,7 +436,7 @@ static void
 _e_book_backend_get_contact_list (EBookBackend *backend,
 				  EDataBook    *book,
 				  guint32       opid,
-				  const char   *query)
+				  const gchar   *query)
 {
 	EBookBackendSyncStatus status;
 	GList *cards = NULL;
@@ -448,7 +450,7 @@ static void
 _e_book_backend_get_changes (EBookBackend *backend,
 			     EDataBook    *book,
 			     guint32       opid,
-			     const char   *change_id)
+			     const gchar   *change_id)
 {
 	EBookBackendSyncStatus status;
 	GList *changes = NULL;
@@ -462,9 +464,9 @@ static void
 _e_book_backend_authenticate_user (EBookBackend *backend,
 				   EDataBook    *book,
 				   guint32       opid,
-				   const char   *user,
-				   const char   *passwd,
-				   const char   *auth_method)
+				   const gchar   *user,
+				   const gchar   *passwd,
+				   const gchar   *auth_method)
 {
 	EBookBackendSyncStatus status;
 
@@ -577,30 +579,3 @@ e_book_backend_sync_class_init (EBookBackendSyncClass *klass)
 
 	object_class->dispose = e_book_backend_sync_dispose;
 }
-
-/**
- * e_book_backend_get_type:
- */
-GType
-e_book_backend_sync_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo info = {
-			sizeof (EBookBackendSyncClass),
-			NULL, /* base_class_init */
-			NULL, /* base_class_finalize */
-			(GClassInitFunc)  e_book_backend_sync_class_init,
-			NULL, /* class_finalize */
-			NULL, /* class_data */
-			sizeof (EBookBackendSync),
-			0,    /* n_preallocs */
-			(GInstanceInitFunc) e_book_backend_sync_init
-		};
-
-		type = g_type_register_static (E_TYPE_BOOK_BACKEND, "EBookBackendSync", &info, 0);
-	}
-
-	return type;
-}
