@@ -48,4 +48,4 @@ CamelMimeFilterHTML      *camel_mime_filter_html_new	(void);
 
 G_END_DECLS
 
-#endif /* ! _CAMEL_MIME_FILTER_HTML_H */
+#endif /* _CAMEL_MIME_FILTER_HTML_H */
