@@ -6,7 +6,7 @@
  *  Dan Winship <danw@ximian.com>
  *  Jeffrey Stedfast <fejj@ximian.com>
  *
- * Copyright 1999, 2000 Ximian, Inc. (www.ximian.com)
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -39,8 +39,6 @@
 #include <glib/gstdio.h>
 #include <gmodule.h>
 
-#include <libedataserver/e-msgport.h>
-
 #include "camel-exception.h"
 #include "camel-private.h"
 #include "camel-provider.h"
@@ -60,14 +58,14 @@ static GStaticRecMutex provider_lock = G_STATIC_REC_MUTEX_INIT;
 static CamelProvider vee_provider = {
 	"vfolder",
 	N_("Virtual folder email provider"),
-	
+
 	N_("For reading mail as a query of another set of folders"),
-	
+
 	"vfolder",
-	
+
 	CAMEL_PROVIDER_IS_STORAGE,
 	CAMEL_URL_NEED_PATH | CAMEL_URL_PATH_IS_ABSOLUTE | CAMEL_URL_FRAGMENT_IS_PATH,
-	
+
 	/* ... */
 };
 
@@ -103,10 +101,10 @@ void
 camel_provider_init (void)
 {
 	GDir *dir;
-	const char *entry;
-	char *p, *name, buf[80];
+	const gchar *entry;
+	gchar *p, *name, buf[80];
 	CamelProviderModule *m;
-	static int loaded = 0;
+	static gint loaded = 0;
 
 	pthread_once(&setup_once, provider_setup);
 
@@ -121,14 +119,14 @@ camel_provider_init (void)
 			  CAMEL_PROVIDERDIR, g_strerror (errno));
 		return;
 	}
-	
+
 	while ((entry = g_dir_read_name (dir))) {
 		FILE *fp;
-		
+
 		p = strrchr (entry, '.');
 		if (!p || strcmp (p, ".urls") != 0)
 			continue;
-		
+
 		name = g_strdup_printf ("%s/%s", CAMEL_PROVIDERDIR, entry);
 		fp = g_fopen (name, "r");
 		if (!fp) {
@@ -137,7 +135,7 @@ camel_provider_init (void)
 			g_free (name);
 			continue;
 		}
-		
+
 		p = strrchr (name, '.');
 		strcpy (p, "." G_MODULE_SUFFIX);
 
@@ -149,9 +147,9 @@ camel_provider_init (void)
 			p = strchr (buf, '\n');
 			if (p)
 				*p = '\0';
-			
+
 			if (*buf) {
-				char *protocol = g_strdup(buf);
+				gchar *protocol = g_strdup(buf);
 
 				m->types = g_slist_prepend(m->types, protocol);
 				g_hash_table_insert(module_table, protocol, m);
@@ -166,16 +164,15 @@ camel_provider_init (void)
 
 /**
  * camel_provider_load:
- * @session: the current session
  * @path: the path to a shared library
  * @ex: a CamelException
  *
  * Loads the provider at @path, and calls its initialization function,
  * passing @session as an argument. The provider should then register
  * itself with @session.
- **/ 
+ **/
 void
-camel_provider_load(const char *path, CamelException *ex)
+camel_provider_load(const gchar *path, CamelException *ex)
 {
 	GModule *module;
 	CamelProvider *(*camel_provider_module_init) (void);
@@ -219,7 +216,7 @@ camel_provider_load(const char *path, CamelException *ex)
 void
 camel_provider_register(CamelProvider *provider)
 {
-	int i;
+	gint i;
 	CamelProviderConfEntry *conf;
 	GList *l;
 
@@ -234,7 +231,7 @@ camel_provider_register(CamelProvider *provider)
 		UNLOCK();
 		return;
 	}
-	
+
 	for (i = 0; i < CAMEL_NUM_PROVIDER_TYPES; i++) {
 		if (provider->object_types[i])
 			provider->service_cache[i] = camel_object_bag_new (provider->url_hash, provider->url_equal,
@@ -263,7 +260,9 @@ camel_provider_register(CamelProvider *provider)
 		l = l->next;
 	}
 
-	g_hash_table_insert(provider_table, provider->protocol, provider);
+	g_hash_table_insert (
+		provider_table,
+		(gpointer) provider->protocol, provider);
 
 	UNLOCK();
 }
@@ -301,7 +300,11 @@ camel_provider_list(gboolean load)
 {
 	GList *list = NULL;
 
-	g_assert(provider_table);
+	/* provider_table can be NULL, so initialize it */
+	if (G_UNLIKELY (provider_table == NULL))
+		camel_provider_init ();
+
+	g_return_val_if_fail (provider_table != NULL, NULL);
 
 	LOCK();
 
@@ -341,14 +344,14 @@ camel_provider_list(gboolean load)
  * Return value: the provider, or %NULL, in which case @ex will be set.
  **/
 CamelProvider *
-camel_provider_get(const char *url_string, CamelException *ex)
+camel_provider_get(const gchar *url_string, CamelException *ex)
 {
 	CamelProvider *provider = NULL;
-	char *protocol;
-	size_t len;
+	gchar *protocol;
+	gsize len;
 
-	g_return_val_if_fail(url_string != NULL, NULL);
-	g_assert(provider_table);
+	g_return_val_if_fail (url_string != NULL, NULL);
+	g_return_val_if_fail (provider_table != NULL, NULL);
 
 	len = strcspn(url_string, ":");
 	protocol = g_alloca(len+1);
@@ -381,16 +384,15 @@ fail:
 	return provider;
 }
 
-
 /**
  * camel_provider_auto_detect:
  * @provider: camel provider
- * @settings: currently set settings
+ * @url: a #CamelURL
  * @auto_detected: output hash table of auto-detected values
  * @ex: exception
  *
  * After filling in the standard Username/Hostname/Port/Path settings
- * (which must be set in @settings), if the provider supports it, you
+ * (which must be set in @url), if the provider supports it, you
  * may wish to have the provider auto-detect further settings based on
  * the aformentioned settings.
  *
@@ -398,12 +400,12 @@ fail:
  * will be set to %NULL. Otherwise the provider will attempt to
  * auto-detect whatever it can and file them into @auto_detected. If
  * for some reason it cannot auto-detect anything (not enough
- * information provided in @settings?) then @auto_deetected will be
+ * information provided in @url?) then @auto_detected will be
  * set to %NULL and an exception may be set to explain why it failed.
  *
- * Returns 0 on success or -1 on fail.
+ * Returns: 0 on success or -1 on fail.
  **/
-int
+gint
 camel_provider_auto_detect (CamelProvider *provider, CamelURL *url,
 			    GHashTable **auto_detected, CamelException *ex)
 {
