@@ -31,6 +31,11 @@
 
 #define GDATA_GOOGLE_SERVICE_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GDATA_TYPE_GOOGLE_SERVICE, GDataGoogleServicePrivate))
 
+static void gdata_google_service_iface_init (GDataServiceIface *iface);
+
+G_DEFINE_TYPE_EXTENDED (GDataGoogleService, gdata_google_service, G_TYPE_OBJECT, 0,
+	G_IMPLEMENT_INTERFACE (GDATA_TYPE_SERVICE, gdata_google_service_iface_init))
+
 static GDataEntry * gdata_google_service_update_entry_with_link (GDataService *service, GDataEntry *entry, const gchar *edit_link, GError **error);
 static GDataEntry * gdata_google_service_insert_entry (GDataService *service, const gchar *feed_url, GDataEntry *entry, GError **error);
 static gboolean     gdata_google_service_delete_entry (GDataService *service, GDataEntry *entry, GError **error);
@@ -63,10 +68,9 @@ struct _GDataGoogleServicePrivate {
 enum {
 	PROP_0,
 	PROP_NAME,
-	PROP_AGENT,
+	PROP_AGENT
 };
 
-
 static const gchar *GOOGLE_CLIENT_LOGIN = "https://www.google.com/accounts/ClientLogin";
 
 GQuark
@@ -99,7 +103,7 @@ send_and_handle_google_redirection (SoupSession *soup_session, SoupMessage *msg)
 
 	if (SOUP_STATUS_IS_REDIRECTION (msg->status_code)) {
 		SoupURI *new_uri;
-		const char *new_loc;
+		const gchar *new_loc;
 
 		new_loc = soup_message_headers_get (msg->response_headers, "Location");
 		g_return_if_fail (new_loc != NULL);
@@ -150,7 +154,6 @@ service_is_authenticated (GDataGoogleService *service)
 		return TRUE;
 }
 
-
 /**
  *
  * gdata_google_service_get_feed:
@@ -181,8 +184,10 @@ gdata_google_service_get_feed (GDataService *service, const gchar *feed_url, GEr
 	priv = GDATA_GOOGLE_SERVICE_GET_PRIVATE( GDATA_GOOGLE_SERVICE(service) );
 	auth = (GDataGoogleServiceAuth *)priv->auth;
 	soup_session = (SoupSession *)priv->soup_session;
-	msg = NULL;
+
 	msg = soup_message_new(SOUP_METHOD_GET, feed_url);
+	if (!msg)
+		return NULL;
 
 	soup_message_headers_append(msg->request_headers,
 			"Authorization", (gchar *)g_strdup_printf("GoogleLogin auth=%s", auth->token));
@@ -211,7 +216,6 @@ gdata_google_service_get_feed (GDataService *service, const gchar *feed_url, GEr
 	return feed;
 }
 
-
 /**
  *
  * gdata_google_service_insert_entry:
@@ -281,7 +285,6 @@ gdata_google_service_insert_entry (GDataService *service, const gchar *feed_url,
 	return updated_entry;
 }
 
-
 /**
  *
  * gdata_google_service_delete_entry:
@@ -301,7 +304,7 @@ gdata_google_service_delete_entry (GDataService *service, GDataEntry *entry, GEr
 	const gchar *entry_edit_url;
 	gboolean retval = FALSE;
 
-	g_return_val_if_fail (service !=NULL, FALSE);
+	g_return_val_if_fail (service != NULL, FALSE);
 	g_return_val_if_fail (GDATA_IS_GOOGLE_SERVICE(service), FALSE);
 
 	if (!service_is_authenticated( GDATA_GOOGLE_SERVICE(service) )) {
@@ -312,7 +315,7 @@ gdata_google_service_delete_entry (GDataService *service, GDataEntry *entry, GEr
 	entry_edit_url = gdata_entry_get_edit_link (entry);
 	priv = GDATA_GOOGLE_SERVICE_GET_PRIVATE (GDATA_GOOGLE_SERVICE (service));
 	auth = (GDataGoogleServiceAuth *) priv->auth;
-	soup_session = 	(SoupSession *)priv->soup_session;
+	soup_session =	(SoupSession *)priv->soup_session;
 
 	msg = soup_message_new (SOUP_METHOD_DELETE, entry_edit_url);
 	soup_message_headers_append (msg->request_headers,
@@ -323,7 +326,7 @@ gdata_google_service_delete_entry (GDataService *service, GDataEntry *entry, GEr
 	/* Handle redirects ourself */
 	send_and_handle_google_redirection (soup_session, msg);
 
-    	if (msg->status_code != 200) {
+	if (msg->status_code != 200) {
 		g_set_error (error, SOUP_HTTP_ERROR,
 					 msg->status_code, "%s", msg->reason_phrase);
 	} else {
@@ -347,17 +350,16 @@ gdata_google_service_delete_entry (GDataService *service, GDataEntry *entry, GEr
 static GDataEntry*
 gdata_google_service_update_entry (GDataService *service, GDataEntry *entry, GError **error)
 {
-	const char *entry_edit_url;
+	const gchar *entry_edit_url;
 
-	g_return_val_if_fail (service !=NULL, FALSE);
-	g_return_val_if_fail (GDATA_IS_GOOGLE_SERVICE (service), FALSE);
+	g_return_val_if_fail (service != NULL, NULL);
+	g_return_val_if_fail (GDATA_IS_GOOGLE_SERVICE (service), NULL);
 
 	entry_edit_url = gdata_entry_get_edit_link (entry);
 
 	return gdata_google_service_update_entry_with_link (service, entry, entry_edit_url, error);
 }
 
-
 /**
  *
  * gdata_google_update_entry_with_link:
@@ -377,9 +379,9 @@ gdata_google_service_update_entry_with_link (GDataService *service, GDataEntry *
 	gchar *entry_xml;
 	GDataEntry *updated_entry = NULL;
 
-	g_return_val_if_fail (service !=NULL, FALSE);
-	g_return_val_if_fail (GDATA_IS_GOOGLE_SERVICE (service), FALSE);
-	g_return_val_if_fail (edit_link !=NULL, FALSE);
+	g_return_val_if_fail (service != NULL, NULL);
+	g_return_val_if_fail (GDATA_IS_GOOGLE_SERVICE (service), NULL);
+	g_return_val_if_fail (edit_link != NULL, NULL);
 
 	if (!service_is_authenticated( GDATA_GOOGLE_SERVICE(service) )) {
 		if (FALSE == gdata_google_service_authenticate(GDATA_GOOGLE_SERVICE(service), error))
@@ -407,7 +409,7 @@ gdata_google_service_update_entry_with_link (GDataService *service, GDataEntry *
 	/* Handle redirects ourself */
 	send_and_handle_google_redirection (soup_session, msg);
 
-    	if (msg->status_code != 200) {
+	if (msg->status_code != 200) {
 		g_set_error (error, SOUP_HTTP_ERROR,
 					 msg->status_code, "%s", msg->reason_phrase);
 		g_object_unref (msg);
@@ -427,10 +429,9 @@ gdata_google_service_update_entry_with_link (GDataService *service, GDataEntry *
 	return updated_entry;
 }
 
-static void gdata_google_service_iface_init(gpointer  g_iface, gpointer iface_data)
+static void
+gdata_google_service_iface_init (GDataServiceIface *iface)
 {
-	GDataServiceIface *iface = (GDataServiceIface *)g_iface;
-
 	iface->set_proxy = gdata_google_service_set_proxy;
 	iface->set_credentials = gdata_google_service_set_credentials;
 	iface->get_feed = gdata_google_service_get_feed;
@@ -441,11 +442,11 @@ static void gdata_google_service_iface_init(gpointer  g_iface, gpointer iface_da
 	return;
 }
 
-static void gdata_google_service_instance_init(GTypeInstance *instance,
-		gpointer      g_class)
+static void
+gdata_google_service_init (GDataGoogleService *instance)
 {
 	GDataGoogleServicePrivate *priv;
-	GDataGoogleService *self = (GDataGoogleService *)instance;
+	GDataGoogleService *self = instance;
 
 	/* Private data set by g_type_class_add_private */
 	priv = GDATA_GOOGLE_SERVICE_GET_PRIVATE(self);
@@ -454,7 +455,6 @@ static void gdata_google_service_instance_init(GTypeInstance *instance,
 	priv->name = NULL;
 	priv->agent = NULL;
 
-
 	priv->auth = g_new0(GDataGoogleServiceAuth,1);
 	priv->auth->username = NULL;
 	priv->auth->password = NULL;
@@ -573,12 +573,9 @@ static void gdata_google_service_set_property (GObject *obj,
 	}
 }
 
-
-static void gdata_google_service_class_init(gpointer g_class,
-		gpointer g_class_data)
+static void gdata_google_service_class_init (GDataGoogleServiceClass *klass)
 {
-	GObjectClass *gobject_class = G_OBJECT_CLASS(g_class);
-	GDataGoogleServiceClass *klass = GDATA_GOOGLE_SERVICE_CLASS(g_class);
+	GObjectClass *gobject_class = G_OBJECT_CLASS(klass);
 
 	g_type_class_add_private(klass, sizeof (GDataGoogleServicePrivate));
 
@@ -587,7 +584,6 @@ static void gdata_google_service_class_init(gpointer g_class,
 	gobject_class->dispose  = gdata_google_service_dispose;
 	gobject_class->finalize = gdata_google_service_finalize;
 
-
 	g_object_class_install_property(gobject_class, PROP_NAME,
 			g_param_spec_string("name", "Name",
 				"The name (e.g. 'cl') of the service",
@@ -598,7 +594,6 @@ static void gdata_google_service_class_init(gpointer g_class,
 				G_PARAM_STATIC_NICK |
 				G_PARAM_STATIC_BLURB));
 
-
 	g_object_class_install_property(gobject_class, PROP_AGENT,
 			g_param_spec_string("agent", "Agent",
 				"The agent (e.g 'evolution', 'tinymail') of the calling program",
@@ -612,46 +607,6 @@ static void gdata_google_service_class_init(gpointer g_class,
 	return;
 }
 
-
-GType  gdata_google_service_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY(type == 0))
-	{
-		static const GTypeInfo info =
-		{
-			sizeof (GDataGoogleServiceClass),
-			NULL,   /* base_init */
-			NULL,   /* base_finalize */
-			(GClassInitFunc) gdata_google_service_class_init, /* class_init */
-			NULL,   /* class_finalize */
-			NULL,   /* class_data */
-			sizeof (GDataGoogleService),
-			0,      /* n_preallocs */
-			gdata_google_service_instance_init    /* instance_init */
-		};
-
-		static const GInterfaceInfo gdata_google_service_iface_info =
-		{
-			(GInterfaceInitFunc) gdata_google_service_iface_init, /* interface_init */
-			NULL,         /* interface_finalize */
-			NULL          /* interface_data */
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-				"GDataGoogleServiceType",
-				&info, 0);
-
-		g_type_add_interface_static (type, GDATA_TYPE_SERVICE,
-				&gdata_google_service_iface_info);
-
-	}
-
-	return type;
-}
-
-
 /*********API******* */
 
 /**
@@ -685,11 +640,11 @@ gdata_google_service_authenticate (GDataGoogleService *service, GError **error)
 	auth = (GDataGoogleServiceAuth *)priv->auth;
 
 	request_form = g_hash_table_new (g_str_hash, g_str_equal);
-	g_hash_table_insert (request_form, "Email", auth->username);
-	g_hash_table_insert (request_form, "Passwd", auth->password);
-	g_hash_table_insert (request_form, "service", priv->name);
-	g_hash_table_insert (request_form, "source", priv->agent);
-	g_hash_table_insert (request_form, "accountType", "HOSTED_OR_GOOGLE");
+	g_hash_table_insert (request_form, (gpointer) "Email", auth->username);
+	g_hash_table_insert (request_form, (gpointer) "Passwd", auth->password);
+	g_hash_table_insert (request_form, (gpointer) "service", priv->name);
+	g_hash_table_insert (request_form, (gpointer) "source", priv->agent);
+	g_hash_table_insert (request_form, (gpointer) "accountType", (gpointer) "HOSTED_OR_GOOGLE");
 	request_body = soup_form_encode_hash (request_form);
 	g_hash_table_destroy (request_form);
 
@@ -701,7 +656,7 @@ gdata_google_service_authenticate (GDataGoogleService *service, GError **error)
 
 	soup_session_send_message (priv->soup_session, msg);
 
-    	if (msg->status_code != 200) {
+	if (msg->status_code != 200) {
 		g_set_error (error, SOUP_HTTP_ERROR,
 					 msg->status_code, "%s", msg->reason_phrase);
 		g_object_unref(msg);
